==> dde-control-center_6.0.78.1.tar.xz: BUILD/translations/keyboard_language_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation>阿法爾語</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>南非語</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>阿姆哈拉語</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>阿拉伯語</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>阿薩姆語</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>阿斯圖里亞斯語</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>白俄羅斯語</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation>白俄羅斯拉丁語</translation>
    </message>
    <message>
        <source>Български</source>
        <translation>保加利亞語</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation>孟加拉語</translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation>孟加拉語（印度）</translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation>藏語</translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation>布列塔尼語</translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>波士尼亞語</translation>
    </message>
    <message>
        <source>Català</source>
        <translation>加泰隆尼亞語</translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation>克里米亞土耳其語</translation>
    </message>
    <message>
        <source>Český</source>
        <translation>捷克語</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation>卡舒比語</translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation>楚瓦什語</translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation>威爾斯語</translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>丹麥語</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>德語</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation>不丹語</translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>希臘語</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>英國英語</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>美國英語</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>西班牙語</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>愛沙尼亞語</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>巴斯克語</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation>波斯語</translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>芬蘭語</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation>法羅語</translation>
    </message>
    <message>
        <source>Français</source>
        <translation>法語</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation>西弗里斯蘭語</translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>愛爾蘭語</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation>蓋爾語</translation>
    </message>
    <message>
        <source>Galego</source>
        <translation>加利西亞語</translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation>古吉拉特語</translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation>曼島語</translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation>豪薩語</translation>
    </message>
    <message>
        <source>עברית</source>
        <translation>希伯拉語</translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation>印地語</translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation>恰蒂斯加爾語</translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>克羅埃西亞語</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation>上索布語</translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>匈牙利語</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation>亞美尼亞語</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>印度尼西亞語</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation>伊努皮克語</translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation>冰島語</translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>義大利語</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>因紐特語</translation>
    </message>
    <message>
        <source>日本語</source>
        <translation>日語</translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation>喬治亞語</translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation>哈薩克語</translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>格稜蘭語</translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation>高棉語</translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation>卡納達語</translation>
    </message>
    <message>
        <source>한국어</source>
        <translation>韓語</translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation>克什米爾語</translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>庫爾德語</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation>康沃爾語</translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation>吉爾吉斯語</translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation>盧森堡語</translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation>林堡語</translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation>寮語</translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>立陶宛語</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>拉脫維亞語</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation>邁蒂利語</translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation>馬達加斯加語</translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation>草原馬里語</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>毛利語</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>馬其頓語</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation>馬拉雅拉姆語</translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>蒙古語</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation>馬拉地語</translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation>馬來語</translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>馬耳他語</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation>緬甸語</translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation>閩南語</translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>挪威語（布克莫爾語）</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation>低地德語</translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation>尼泊爾語</translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>荷蘭語</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>挪威語（新挪威語）</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation>南恩德貝勒語</translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation>北索托語</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation>奧克語</translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation>奧羅莫語</translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation>奧里亞語</translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation>奧塞梯語</translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation>旁遮普語</translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>波蘭語</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation>普什圖語</translation>
    </message>
    <message>
        <source>Português</source>
        <translation>葡萄牙語</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>葡萄牙語（巴西）</translation>
    </message>
    <message>
        <source>Română</source>
        <translation>羅馬尼亞語</translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>俄語</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation>盧安達語</translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation>梵語</translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation>薩丁尼亞語</translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation>信德語</translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation>北薩米語</translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation>僧伽羅語</translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>斯洛伐克語</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>斯洛維尼亞語</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation>索馬利亞語</translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>阿爾巴尼亞語</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>塞爾維亞語</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>塞爾維亞語（拉丁）</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation>斯瓦蒂語</translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation>南索托語</translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>瑞典語</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation>斯瓦希里語</translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation>泰米爾語</translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation>泰盧固語</translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation>塔吉克語</translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation>泰語</translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation>提格利尼亞語</translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>土庫曼語</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation>茨瓦納語</translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>土耳其語</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation>聰加語</translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>韃靼語</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation>維語</translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>烏克蘭語</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation>烏爾都語</translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation>烏茲別克語</translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>烏茲別克語（西里爾文）</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation>文達語</translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation>越南語</translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>瓦隆語</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation>沃洛夫語</translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation>科薩語</translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation>意第緒語</translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation>約魯巴語</translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation>簡體中文</translation>
    </message>
    <message>
        <source>繁體中文（中國香港）</source>
        <translation>繁體中文（中國香港）</translation>
    </message>
    <message>
        <source>繁體中文（中國臺灣）</source>
        <translation>繁體中文（中國臺灣）</translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation>祖魯語</translation>
    </message>
</context>
</TS>

==> dde-control-center_6.1.22.tar.xz: BUILD/translations/keyboard_language_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <source>Afar</source>
        <translation>阿法爾語</translation>
    </message>
    <message>
        <source>Afrikaans</source>
        <translation>南非語</translation>
    </message>
    <message>
        <source>አማርኛ</source>
        <translation>阿姆哈拉語</translation>
    </message>
    <message>
        <source>عربية</source>
        <translation>阿拉伯語</translation>
    </message>
    <message>
        <source>অসমীয়া</source>
        <translation>阿薩姆語</translation>
    </message>
    <message>
        <source>Asturianu</source>
        <translation>阿斯圖里亞斯語</translation>
    </message>
    <message>
        <source>Беларуская</source>
        <translation>白俄羅斯語</translation>
    </message>
    <message>
        <source>Biełaruskaja łacinka</source>
        <translation>白俄羅斯拉丁語</translation>
    </message>
    <message>
        <source>Български</source>
        <translation>保加利亞語</translation>
    </message>
    <message>
        <source>বাংলা</source>
        <translation>孟加拉語</translation>
    </message>
    <message>
        <source>বাংলা (ভারত)</source>
        <translation>孟加拉語（印度）</translation>
    </message>
    <message>
        <source>བོད་སྐད།</source>
        <translation>藏語</translation>
    </message>
    <message>
        <source>Brezhoneg</source>
        <translation>布列塔尼語</translation>
    </message>
    <message>
        <source>Bosanski</source>
        <translation>波士尼亞語</translation>
    </message>
    <message>
        <source>Català</source>
        <translation>加泰隆尼亞語</translation>
    </message>
    <message>
        <source>Qırımtatarca</source>
        <translation>克里米亞土耳其語</translation>
    </message>
    <message>
        <source>Český</source>
        <translation>捷克語</translation>
    </message>
    <message>
        <source>Kaszëbsczi</source>
        <translation>卡舒比語</translation>
    </message>
    <message>
        <source>Чăвашла</source>
        <translation>楚瓦什語</translation>
    </message>
    <message>
        <source>Cymraeg</source>
        <translation>威爾斯語</translation>
    </message>
    <message>
        <source>Dansk</source>
        <translation>丹麥語</translation>
    </message>
    <message>
        <source>Deutsch</source>
        <translation>德語</translation>
    </message>
    <message>
        <source>ཇོང་ཁ</source>
        <translation>不丹語</translation>
    </message>
    <message>
        <source>Ελληνικά</source>
        <translation>希臘語</translation>
    </message>
    <message>
        <source>British English</source>
        <translation>英國英語</translation>
    </message>
    <message>
        <source>American English</source>
        <translation>美國英語</translation>
    </message>
    <message>
        <source>Español</source>
        <translation>西班牙語</translation>
    </message>
    <message>
        <source>Eesti</source>
        <translation>愛沙尼亞語</translation>
    </message>
    <message>
        <source>Euskara</source>
        <translation>巴斯克語</translation>
    </message>
    <message>
        <source>فارسی</source>
        <translation>波斯語</translation>
    </message>
    <message>
        <source>Suomi</source>
        <translation>芬蘭語</translation>
    </message>
    <message>
        <source>Føroyskt</source>
        <translation>法羅語</translation>
    </message>
    <message>
        <source>Français</source>
        <translation>法語</translation>
    </message>
    <message>
        <source>Frysk</source>
        <translation>西弗里斯蘭語</translation>
    </message>
    <message>
        <source>Gaeilge</source>
        <translation>愛爾蘭語</translation>
    </message>
    <message>
        <source>Gàidhlig</source>
        <translation>蓋爾語</translation>
    </message>
    <message>
        <source>Galego</source>
        <translation>加利西亞語</translation>
    </message>
    <message>
        <source>ગુજરાતી </source>
        <translation>古吉拉特語</translation>
    </message>
    <message>
        <source>Gaelg</source>
        <translation>曼島語</translation>
    </message>
    <message>
        <source>هَوُسَ</source>
        <translation>豪薩語</translation>
    </message>
    <message>
        <source>עברית</source>
        <translation>希伯拉語</translation>
    </message>
    <message>
        <source>हिन्दी</source>
        <translation>印地語</translation>
    </message>
    <message>
        <source>Chhattisgarhi</source>
        <translation>恰蒂斯加爾語</translation>
    </message>
    <message>
        <source>Hrvatski</source>
        <translation>克羅埃西亞語</translation>
    </message>
    <message>
        <source>Hornjoserbsce</source>
        <translation>上索布語</translation>
    </message>
    <message>
        <source>Magyar</source>
        <translation>匈牙利語</translation>
    </message>
    <message>
        <source>Հայերեն</source>
        <translation>亞美尼亞語</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>印度尼西亞語</translation>
    </message>
    <message>
        <source>Iñupiak</source>
        <translation>伊努皮克語</translation>
    </message>
    <message>
        <source>Íslenska</source>
        <translation>冰島語</translation>
    </message>
    <message>
        <source>Italiano</source>
        <translation>義大利語</translation>
    </message>
    <message>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>因紐特語</translation>
    </message>
    <message>
        <source>日本語</source>
        <translation>日語</translation>
    </message>
    <message>
        <source>ქართული</source>
        <translation>喬治亞語</translation>
    </message>
    <message>
        <source>Қазақша</source>
        <translation>哈薩克語</translation>
    </message>
    <message>
        <source>Kalaallisut</source>
        <translation>格稜蘭語</translation>
    </message>
    <message>
        <source>ខ្មែរ</source>
        <translation>高棉語</translation>
    </message>
    <message>
        <source>ಕನ್ನಡ</source>
        <translation>卡納達語</translation>
    </message>
    <message>
        <source>한국어</source>
        <translation>韓語</translation>
    </message>
    <message>
        <source>कश्मीरी - (كشميري)</source>
        <translation>克什米爾語</translation>
    </message>
    <message>
        <source>Kurdî</source>
        <translation>庫爾德語</translation>
    </message>
    <message>
        <source>Kernewek</source>
        <translation>康沃爾語</translation>
    </message>
    <message>
        <source>Кыргызча</source>
        <translation>吉爾吉斯語</translation>
    </message>
    <message>
        <source>Lëtzebuergesch</source>
        <translation>盧森堡語</translation>
    </message>
    <message>
        <source>Limburgs</source>
        <translation>林堡語</translation>
    </message>
    <message>
        <source>ລາວ</source>
        <translation>寮語</translation>
    </message>
    <message>
        <source>Lietuvių</source>
        <translation>立陶宛語</translation>
    </message>
    <message>
        <source>Latviešu</source>
        <translation>拉脫維亞語</translation>
    </message>
    <message>
        <source>Maithili</source>
        <translation>邁蒂利語</translation>
    </message>
    <message>
        <source>Malagasy</source>
        <translation>馬達加斯加語</translation>
    </message>
    <message>
        <source>Ebon</source>
        <translation>草原馬里語</translation>
    </message>
    <message>
        <source>Māori</source>
        <translation>毛利語</translation>
    </message>
    <message>
        <source>Македонски</source>
        <translation>馬其頓語</translation>
    </message>
    <message>
        <source>മലയാളം</source>
        <translation>馬拉雅拉姆語</translation>
    </message>
    <message>
        <source>Монгол</source>
        <translation>蒙古語</translation>
    </message>
    <message>
        <source>मराठी</source>
        <translation>馬拉地語</translation>
    </message>
    <message>
        <source>Bahasa Melayu</source>
        <translation>馬來語</translation>
    </message>
    <message>
        <source>Malti</source>
        <translation>馬耳他語</translation>
    </message>
    <message>
        <source>Myanmasa</source>
        <translation>緬甸語</translation>
    </message>
    <message>
        <source>Ekakairũ Naoero</source>
        <translation>閩南語</translation>
    </message>
    <message>
        <source>Norsk (bokmål)</source>
        <translation>挪威語（布克莫爾語）</translation>
    </message>
    <message>
        <source>Plattdüütsch</source>
        <translation>低地德語</translation>
    </message>
    <message>
        <source>नेपाली</source>
        <translation>尼泊爾語</translation>
    </message>
    <message>
        <source>Nederlands</source>
        <translation>荷蘭語</translation>
    </message>
    <message>
        <source>Norsk (nynorsk)</source>
        <translation>挪威語（新挪威語）</translation>
    </message>
    <message>
        <source>IsiNdebele</source>
        <translation>南恩德貝勒語</translation>
    </message>
    <message>
        <source>Sesotho sa Leboa</source>
        <translation>北索托語</translation>
    </message>
    <message>
        <source>Occitan</source>
        <translation>奧克語</translation>
    </message>
    <message>
        <source>Oromoo</source>
        <translation>奧羅莫語</translation>
    </message>
    <message>
        <source>ଓଡ଼ିଆ</source>
        <translation>奧里亞語</translation>
    </message>
    <message>
        <source>Иронау</source>
        <translation>奧塞梯語</translation>
    </message>
    <message>
        <source>ਪੰਜਾਬੀ</source>
        <translation>旁遮普語</translation>
    </message>
    <message>
        <source>Polski</source>
        <translation>波蘭語</translation>
    </message>
    <message>
        <source>پښتو</source>
        <translation>普什圖語</translation>
    </message>
    <message>
        <source>Português</source>
        <translation>葡萄牙語</translation>
    </message>
    <message>
        <source>Português do Brasil</source>
        <translation>葡萄牙語（巴西）</translation>
    </message>
    <message>
        <source>Română</source>
        <translation>羅馬尼亞語</translation>
    </message>
    <message>
        <source>Русский</source>
        <translation>俄語</translation>
    </message>
    <message>
        <source>Kinyarwanda</source>
        <translation>盧安達語</translation>
    </message>
    <message>
        <source>संस्कृत</source>
        <translation>梵語</translation>
    </message>
    <message>
        <source>Sardu</source>
        <translation>薩丁尼亞語</translation>
    </message>
    <message>
        <source>سنڌي</source>
        <translation>信德語</translation>
    </message>
    <message>
        <source>Sámegiella</source>
        <translation>北薩米語</translation>
    </message>
    <message>
        <source>සිංහල</source>
        <translation>僧伽羅語</translation>
    </message>
    <message>
        <source>Slovenčina</source>
        <translation>斯洛伐克語</translation>
    </message>
    <message>
        <source>Slovenščina</source>
        <translation>斯洛維尼亞語</translation>
    </message>
    <message>
        <source>Soomaaliga</source>
        <translation>索馬利亞語</translation>
    </message>
    <message>
        <source>Shqip</source>
        <translation>阿爾巴尼亞語</translation>
    </message>
    <message>
        <source>Српски</source>
        <translation>塞爾維亞語</translation>
    </message>
    <message>
        <source>srpski (latinica)</source>
        <translation>塞爾維亞語（拉丁）</translation>
    </message>
    <message>
        <source>SiSwati</source>
        <translation>斯瓦蒂語</translation>
    </message>
    <message>
        <source>Sesotho</source>
        <translation>南索托語</translation>
    </message>
    <message>
        <source>Svenska</source>
        <translation>瑞典語</translation>
    </message>
    <message>
        <source>Swahili</source>
        <translation>斯瓦希里語</translation>
    </message>
    <message>
        <source>தமிழ்</source>
        <translation>泰米爾語</translation>
    </message>
    <message>
        <source>తెలుగు</source>
        <translation>泰盧固語</translation>
    </message>
    <message>
        <source>Тоҷикӣ</source>
        <translation>塔吉克語</translation>
    </message>
    <message>
        <source>ภาษาไทย</source>
        <translation>泰語</translation>
    </message>
    <message>
        <source>ትግርኛ</source>
        <translation>提格利尼亞語</translation>
    </message>
    <message>
        <source>Türkmen</source>
        <translation>土庫曼語</translation>
    </message>
    <message>
        <source>Setswana</source>
        <translation>茨瓦納語</translation>
    </message>
    <message>
        <source>Türkçe</source>
        <translation>土耳其語</translation>
    </message>
    <message>
        <source>Xitsonga</source>
        <translation>聰加語</translation>
    </message>
    <message>
        <source>Татарский</source>
        <translation>韃靼語</translation>
    </message>
    <message>
        <source>ئۇيغۇرچە</source>
        <translation>維語</translation>
    </message>
    <message>
        <source>Українська</source>
        <translation>烏克蘭語</translation>
    </message>
    <message>
        <source>اردو</source>
        <translation>烏爾都語</translation>
    </message>
    <message>
        <source>Oʻzbekcha</source>
        <translation>烏茲別克語</translation>
    </message>
    <message>
        <source>Uzbek (Cyrillic)</source>
        <translation>烏茲別克語（西里爾文）</translation>
    </message>
    <message>
        <source>Venda</source>
        <translation>文達語</translation>
    </message>
    <message>
        <source>Tiếng Việt</source>
        <translation>越南語</translation>
    </message>
    <message>
        <source>Walon</source>
        <translation>瓦隆語</translation>
    </message>
    <message>
        <source>Wolof</source>
        <translation>沃洛夫語</translation>
    </message>
    <message>
        <source>isixhosa</source>
        <translation>科薩語</translation>
    </message>
    <message>
        <source>ייִדיש</source>
        <translation>意第緒語</translation>
    </message>
    <message>
        <source>Yorùbá</source>
        <translation>約魯巴語</translation>
    </message>
    <message>
        <source>简体中文</source>
        <translation>簡體中文</translation>
    </message>
    <message>
        <source>繁體中文(中國香港)</source>
        <translation>繁體中文（中國香港）</translation>
    </message>
    <message>
        <source>繁體中文</source>
        <translation>繁體中文（中國台灣）</translation>
    </message>
    <message>
        <source>isiZulu</source>
        <translation>祖魯語</translation>
    </message>
</context>
</TS>
